==> saxs_V2.458P2.027E2.223.tgz: saxs/src/isotime2epoch.c <==
/***************************************************************************/
/* Written 1994++ by Peter Boesecke                                        */
/* Copyright (C) 2011 European Synchrotron Radiation Facility              */
/*                       Grenoble, France                                  */
/*                                                                         */
/*    Principal authors: Peter Boesecke  (boesecke@esrf.eu)                */
/*                                                                         */
/*    This program is free software: you can redistribute it and/or modify */
/*    it under the terms of the GNU General Public License as published by */
/*    the Free Software Foundation, either version 3 of the License, or    */
/*    (at your option) any later version.                                  */
/*                                                                         */
/*    This program is distributed in the hope that it will be useful,      */
/*    but WITHOUT ANY WARRANTY; without even the implied warranty of       */
/*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
/*    GNU General Public License for more details.                         */
/*                                                                         */
/*    You should have received a copy of the GNU General Public License    */
/*    along with this program.  If not, see <http://www.gnu.org/licenses/>.*/
/***************************************************************************/
# define Version  "isotime2epoch 1.1 2006-06-02, Peter Boesecke"
/*---------------------------------------------------------------------------
NAME
  isotime2epoch - convert isotime string to epoch (seconds since 1970-01-01)

SYNOPSIS
  isotime2epoch {<isotime string>} 

DESCRIPTION
  Converts isotime string from argument list or from stdin to epoch and 
  returns the result to stdout.
  stdin is only read if no isotime string is given in the argument list.

  isotime2epoch [options] "2006-06-01 11:43:09.479230"

  isotime2epoch [options] < file

  The file must contain 1 isotime string per line. The conversion stops
  at eof, "quit" or "exit"

HISTORY
  V1.0 2006-05-30 Peter Boesecke
  V1.1 2006-06-02 Peter Boesecke
---------------------------------------------------------------------------*/

# include "isotime.h"

/* removes trailing line feed \n */
char * trimlf ( char * s )
{ size_t slen;
  if ( s ) { 
    slen = strlen( s );
    if ( slen > 0 )      
      if (s[slen-1]=='\n') s[slen-1]='\0';
  }
  return ( s );
} // trimlf

/* returns 1 if s is an empty string (only white space) otherwise 0. */
int isempty( const char *s )
{ const char *ps;
  int empty=1;
  
  if (s) {
    ps = s;
    while (*ps) { empty = empty && isspace(*ps); ps++; }
  }
  return( empty );

} //isempty

/*+++------------------------------------------------------------------------
main
---------------------------------------------------------------------------*/

#if MAKE_FUNCTION
# define MAIN main_isotime2epoch
#else
# define MAIN main
#endif

int MAIN (int argc, char *argv[])
{ char *nul = (char *) NULL;
  char **pargv;
  IsotimeEpoch epoch;
  int status=0;
  const char *ps, *offset="";
  long debug=0;
  float tmp=0.0;
  int argconv=0; // is set to 1 if an isotime argument is found
  char * string;

  #define BUFLEN 1024
  char buffer[BUFLEN];

  // count options or help or help
  pargv = &argv[1];

  for (;*pargv!=nul;*pargv++) {
    if (( strncmp( *pargv,"-h",2 )==0 )||( strncmp( *pargv,"--help",6 )==0 )) {
      // help
      fprintf( stderr, "%s\n", Version );
      fprintf( stderr, "%s\n", isotime_version() );
      fprintf( stderr, 
        "isotime2epoch [-h] [debug=0|1] [offset=+|-HhMm] {<isotime>}\n" );
      return( 1 );
    } else if ( strncmp( *pargv,"debug=", 6 ) == 0 ) {
      // set debug level
      ps=*pargv+6;
      sscanf(ps,"%ld",&debug);
      isotime_debug(debug);
    } else if ( strncmp( *pargv,"offset=", 7 ) == 0 ) {
      // set offset 
      offset=*pargv+7;
    } else {
      // convert isotime to epoch
      argconv=1;
      epoch = addoffset2epoch( isotime2epoch( *pargv ), offset);
      if (epoch.status) {
        status=epoch.status;
        fprintf( stderr,"ERROR: Time read failed.\n");
      } else {
        fprintf( stdout,"%s\n", epoch2string(buffer,BUFLEN,epoch) );
      }
    }
  }
  if (!argconv) {
    // read from standard input
    while ( !feof( stdin ) ) {
      string = fgets ( buffer, BUFLEN, stdin );

      if ( string ) {
        if ( (!strncmp(string,"exit",4)) || (!strncmp(string,"quit",4)) )
          return ( status );
        // convert isotime to epoch
        if (!isempty (string)) {
          epoch = addoffset2epoch( isotime2epoch( string ), offset);
          if (epoch.status) {
            status=epoch.status;
            fprintf( stderr,"ERROR: Time read failed.\n");
          } else {
            fprintf( stdout,"%s\n", epoch2string(buffer,BUFLEN,epoch) );
          }
        } else fprintf( stdout,"\n");
      }
    }
  }
  return( status );
} /* MAIN */

==> saxs_V2.459P2.033E2.229.tgz: saxs/src/isotime2epoch.c <==
/***************************************************************************/
/* Written 1994++ by Peter Boesecke                                        */
/* Copyright (C) 2011 European Synchrotron Radiation Facility              */
/*                       Grenoble, France                                  */
/*                                                                         */
/*    Principal authors: Peter Boesecke  (boesecke@esrf.eu)                */
/*                                                                         */
/*    This program is free software: you can redistribute it and/or modify */
/*    it under the terms of the GNU General Public License as published by */
/*    the Free Software Foundation, either version 3 of the License, or    */
/*    (at your option) any later version.                                  */
/*                                                                         */
/*    This program is distributed in the hope that it will be useful,      */
/*    but WITHOUT ANY WARRANTY; without even the implied warranty of       */
/*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
/*    GNU General Public License for more details.                         */
/*                                                                         */
/*    You should have received a copy of the GNU General Public License    */
/*    along with this program.  If not, see <http://www.gnu.org/licenses/>.*/
/***************************************************************************/
# define Version  "isotime2epoch 1.2 2012-10-28, Peter Boesecke"
/*---------------------------------------------------------------------------
NAME
  isotime2epoch - convert isotime string to epoch (seconds since 1970-01-01)

SYNOPSIS
  isotime2epoch {<isotime string>} 

DESCRIPTION
  Converts isotime string from argument list or from stdin to epoch and 
  returns the result to stdout.
  stdin is only read if no isotime string is given in the argument list.

  isotime2epoch [options] "2006-06-01 11:43:09.479230"

  isotime2epoch [options] < file

  The file must contain 1 isotime string per line. The conversion stops
  at eof, "quit" or "exit"

HISTORY
  V1.0 2006-05-30 Peter Boesecke
  V1.1 2006-06-02 PB
  V1.2 2012-10-28 PB shift added
---------------------------------------------------------------------------*/

# include "isotime.h"

/* removes trailing line feed \n */
char * trimlf ( char * s )
{ size_t slen;
  if ( s ) { 
    slen = strlen( s );
    if ( slen > 0 )      
      if (s[slen-1]=='\n') s[slen-1]='\0';
  }
  return ( s );
} // trimlf

/* returns 1 if s is an empty string (only white space) otherwise 0. */
int isempty( const char *s )
{ const char *ps;
  int empty=1;
  
  if (s) {
    ps = s;
    while (*ps) { empty = empty && isspace(*ps); ps++; }
  }
  return( empty );

} //isempty

/*+++------------------------------------------------------------------------
main
---------------------------------------------------------------------------*/

#if MAKE_FUNCTION
# define MAIN main_isotime2epoch
#else
# define MAIN main
#endif

int MAIN (int argc, char *argv[])
{ char *nul = (char *) NULL;
  char **pargv;
  IsotimeEpoch epoch;
  int status=0;
  const char *ps, *offset="", *shift="";
  long debug=0;
  float tmp=0.0;
  int argconv=0; // is set to 1 if an isotime argument is found
  char * string;

  #define BUFLEN 1024
  char buffer[BUFLEN];

  // count options or help or help
  pargv = &argv[1];

  for (;*pargv!=nul;*pargv++) {
    if (( strncmp( *pargv,"-h",2 )==0 )||( strncmp( *pargv,"--help",6 )==0 )) {
      // help
      fprintf( stderr, "%s\n", Version );
      fprintf( stderr, "%s\n", isotime_version() );
      fprintf( stderr, 
        "isotime2epoch [-h] [debug=0|1] [offset=+|-HhMm] [shift=<seconds>] {<isotime>}\n" );
      return( 1 );
    } else if ( strncmp( *pargv,"debug=", 6 ) == 0 ) {
      // set debug level
      ps=*pargv+6;
      sscanf(ps,"%ld",&debug);
      isotime_debug(debug);
    } else if ( strncmp( *pargv,"offset=", 7 ) == 0 ) {
      // set offset 
      offset=*pargv+7;
    } else if ( strncmp( *pargv,"shift=", 6 ) == 0 ) {
      // set shift
      shift=*pargv+6;
    } else {
      // convert isotime to epoch
      argconv=1;
      epoch = addoffset2epoch( shiftepoch( isotime2epoch( *pargv ), 
                                           string2epoch( shift ) ), offset);
      if (epoch.status) {
        status=epoch.status;
        fprintf( stderr,"ERROR: Time read failed.\n");
      } else {
        fprintf( stdout,"%s\n", epoch2string(buffer,BUFLEN,epoch) );
      }
    }
  }
  if (!argconv) {
    // read from standard input
    while ( !feof( stdin ) ) {
      string = fgets ( buffer, BUFLEN, stdin );

      if ( string ) {
        if ( (!strncmp(string,"exit",4)) || (!strncmp(string,"quit",4)) )
          return ( status );
        // convert isotime to epoch
        if (!isempty (string)) {
          epoch = addoffset2epoch( shiftepoch( isotime2epoch( string ),
                                               string2epoch( shift ) ),offset);
          if (epoch.status) {
            status=epoch.status;
            fprintf( stderr,"ERROR: Time read failed.\n");
          } else {
            fprintf( stdout,"%s\n", epoch2string(buffer,BUFLEN,epoch) );
          }
        } else fprintf( stdout,"\n");
      }
    }
  }
  return( status );
} /* MAIN */
